@@ -25,6 +25,12 @@ def urls_from_text(string):
     """
     for match in re.finditer(URL_IN_TEXT_RE, string):
         url = match.group(0)
+        s = match.start()
+
+        if s > 0 and string[s - 1] == '[':
+            if '](' in url:
+                remainder, url = url.split('](', 1)
+                yield remainder.strip()
 
         last_punct = None
 
